@@ -58,6 +58,7 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-link.h"
 #include "nautilus-trash-monitor.h"
+#include "nautilus-file-utilities.h"
 
 typedef enum   TransferKind         TransferKind;
 typedef struct TransferInfo         TransferInfo;
@@ -431,7 +432,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 
 	if (from_uri != NULL) {
 		uri = gnome_vfs_uri_new (from_uri);
-		item = gnome_vfs_uri_extract_short_name (uri);
+		item = nautilus_get_uri_shortname_for_display (uri);
 		from_path = gnome_vfs_uri_extract_dirname (uri);
 		hostname = NULL;
 
@@ -1255,6 +1256,18 @@ get_link_name (char *name, int count)
 
 	unescaped_name = g_filename_to_utf8 (unescaped_tmp_name, -1,
 					     NULL, NULL, NULL);
+
+	if (!unescaped_name) {
+		/* Couldn't convert to utf8 - probably
+		 * G_BROKEN_FILENAMES not set when it should be.
+		 * Try converting from the locale */
+		unescaped_name = g_locale_to_utf8 (unescaped_tmp_name, -1, NULL, NULL, NULL);	
+
+		if (!unescaped_name) {
+			unescaped_name = eel_make_valid_utf8 (unescaped_tmp_name);
+		}
+	}
+
 	g_free (unescaped_tmp_name);
 
 	if (count < 1) {
